@@ -1,3 +1,4 @@
+from __future__ import annotations
 import math
 import operator
 from os import path
@@ -7,7 +8,7 @@ import pandas as pd
 
 import numpy as np
 import arviz as az
-import pymc3 as pm
+import pymc as pm
 import matplotlib.pyplot as plt
 
 plt.style.use("seaborn-whitegrid")
@@ -51,7 +52,7 @@ def inverse_logit(
     x: Union[Iterable[Real], Real], a: Real, b: Real, c: Real, d: Real
 ) -> Union[Iterable, Real]:
     """
-    Inverse logit function at point x.
+    Inverse logit function.
 
     :param x: x.
     :param a: Location of inflection point on x-axis.
@@ -119,7 +120,28 @@ def index_to_titer(
     """
     _check_start_fold_valid(start, fold)
     index = np.array(index) if isinstance(index, (list, tuple)) else index
-    return start * fold ** index
+    return start * fold**index
+
+
+class UnitScaler:
+    """Scale data to a range of 0-1."""
+
+    Array = Union[pd.Series, np.ndarray]
+
+    def fit(self, data: Array) -> UnitScaler:
+        self.data_min = data.min()
+        self.data_range = data.max() - data.min()
+        return self
+
+    def transform(self, array: Array) -> Array:
+        return (array - self.data_min) / self.data_range
+
+    def inverse_transform(self, array: Array) -> Array:
+        return array * self.data_range + self.data_min
+
+    def fit_transform(self, array: Array) -> Array:
+        self.fit(array)
+        return self.transform(array)
 
 
 class Sigmoid:
@@ -133,6 +155,10 @@ class Sigmoid:
     partially pooling inference across samples (`partial` vs `full`).
     Parameters can also be fixed *a priori*, by providing a float.
 
+    Response values are standardised to have a range of 0-1 prior to inference.
+    Log dilution values are standardised to have a mean of 0 and standard
+    deviation of 1 prior to inference.
+
     :param a: ``'partial'``, ``'full'`` or float.
     :param b: ``'partial'``, ``'full'`` or float.
     :param c: ``'partial'``, ``'full'`` or float.
@@ -175,14 +201,14 @@ class Sigmoid:
         """
         Fit parameters of the sigmoid curve to data.
 
-        :param log_diluton: Log diluton values.
+        :param log_dilution: Log dilution values.
         :param response: Response values.
         :param sample_labels: Sample labels.
         :param data: Optional DataFrame. If supplied then `log_dilutions`,
             `response`, and `sample_labels` should be columns in the DataFrame.
         :param draws: Number of samples to draw from the posterior distribution.
         :param kwds: Passed to :py:func:`pymc3.sample`.
-        :param prior_predictive: Sample from the prior predicitve distribution.
+        :param prior_predictive: Sample from the prior predictive distribution.
             The returned Sigmoid object has a `prior_predictive` attribute.
         :returns: Sigmoid object with `posterior` attribute.
         """
@@ -232,16 +258,22 @@ class Sigmoid:
         sample_idx = np.array([uniq_samples.index(sample) for sample in sample_labels])
         sample_i = {sample: uniq_samples.index(sample) for sample in sample_labels}
 
+        # Scale x values to have mean of 0 and std deviation of 1
         mu_log_dilution = np.mean(log_dilution)
         sd_log_dilution = np.std(log_dilution)
         x = (log_dilution - mu_log_dilution) / sd_log_dilution
 
+        # Scale reponse (y) values to have min of 0 and max of 1
+        y_scaler = UnitScaler().fit(response)
+        y = y_scaler.transform(response)
+
         with pm.Model() as self.model:
 
             if self.a == "partial":
                 mu_a = pm.Normal("mu_a", 0, 1)
                 sigma_a = pm.Exponential("sigma_a", 1)
-                a = pm.Normal("a", mu_a, sigma_a, shape=n_samples)[sample_idx]
+                a_unit = pm.Normal("a_unit", 0, 1, shape=n_samples)
+                a = pm.Deterministic("a", a_unit * sigma_a + mu_a)[sample_idx]
             elif self.a == "full":
                 a = pm.Normal("a", 0, 1)
             else:
@@ -250,7 +282,8 @@ class Sigmoid:
             if self.b == "partial":
                 mu_b = pm.Normal("mu_b", 0, 1)
                 sigma_b = pm.Exponential("sigma_b", 1)
-                b = pm.Normal("b", mu_b, sigma_b, shape=n_samples)[sample_idx]
+                b_unit = pm.Normal("b_unit", 0, 1, shape=n_samples)
+                b = pm.Deterministic("b", b_unit * sigma_b + mu_b)[sample_idx]
             elif self.b == "full":
                 b = pm.Normal("b", 0, 1)
             else:
@@ -259,7 +292,8 @@ class Sigmoid:
             if self.c == "partial":
                 mu_c = pm.Normal("mu_c", 0, 1)
                 sigma_c = pm.Exponential("sigma_c", 1)
-                c = pm.Normal("c", mu_c, sigma_c, shape=n_samples)[sample_idx]
+                c_unit = pm.Normal("b_unit", 0, 1, shape=n_samples)
+                c = pm.Deterministic("c", c_unit * sigma_c + mu_c)[sample_idx]
             elif self.c == "full":
                 c = pm.Normal("c", 0, 1)
             else:
@@ -275,13 +309,16 @@ class Sigmoid:
 
             sigma = pm.Exponential("sigma", 1)
             mu = c + d * pm.math.invlogit(-b * (x - a))
-            pm.Normal("lik", mu, sigma, observed=response)
+            pm.Normal("lik", mu, sigma, observed=y)
+
             if prior_predictive:
                 sigmoid.prior_predictive = pm.sample_prior_predictive()
+
             sigmoid.posterior = pm.sample(
                 draws=draws, return_inferencedata=False, **kwds
             )
 
+        sigmoid.y_scaler = y_scaler
         sigmoid.mu_log_dilution = mu_log_dilution
         sigmoid.sd_log_dilution = sd_log_dilution
         sigmoid.sample_i = sample_i
@@ -302,8 +339,8 @@ class Sigmoid:
         sample: Hashable,
         points: bool = True,
         mean: bool = False,
-        scatter_kwds=None,
-        line_kwds=None,
+        scatter_kwds: dict = None,
+        line_kwds: dict = None,
         step: int = 1000,
         match_point_color_to_line_color: bool = False,
         xmin: Real = None,
@@ -316,8 +353,8 @@ class Sigmoid:
         :param points: Whether to plot the data as well.
         :param mean: Show the mean of the posterior distribution, rather than samples
             from the posterior.
-        :param scatter_kwds: Passed to :py:func:`matplotlib.pyplot.scatter`. Used to control the
-            appearance of the data points.
+        :param scatter_kwds: Passed to :py:func:`matplotlib.pyplot.scatter`.
+            Used to control the appearance of the data points.
         :param line_kwds: Passed to :py:func:`matplotlib.pyplot.plot`. Used to control the
             appearance of the lines.
         :param step: Show every step'th sample from the posterior. Only has an
@@ -359,6 +396,7 @@ class Sigmoid:
                 params[param] = value
         ygrid = inverse_logit(xgrid, **params)
         ygrid = ygrid.mean(axis=1) if mean else ygrid
+        ygrid = self.y_scaler.inverse_transform(ygrid)
         lines = plt.plot(self.inverse_scale(xgrid), ygrid, **line_kwds)
 
         if points:
@@ -474,8 +512,8 @@ class Sigmoid:
         """
         Compute endpoints for each sample, given some response. An endpoint is
         the dilution at which a particular value of the response is obtained,
-        known as the cutoff. The cutoff is either in absolute units, or given as
-        a proportion of `d`.
+        known as the cut-off. The cut-off is either in absolute units, or given
+        as a proportion of `d`.
 
         Must supply exactly one of either `cutoff_proportion` or `cutoff_absolute`.
 
